=begin
=TC_Assertions.rb
Contains tests for the Assertions module
=end

#<standard_header>
#
# Copyright (C) 2000-2001 Nathaniel Talbott
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#</standard_header>

require 'Lapidary/TestCase'
require 'Lapidary/TF_Assertions'

module Lapidary
	class TC_Assertions < TestCase
		def setup
			@fixture = TF_Assertions.new
		end
		def fails?
			catch :assertionFailed do
				yield
				return false
			end
			return true
		end
		def testSuccessfulAssertBlock
			assert(! fails?{@fixture.successfulAssertBlock()})
			assert(@fixture.successfulMessage == "successful assertBlock")
		end
		def testFailedAssertBlock
			assert(fails?{@fixture.failedAssertBlockPlain()})
			assert(fails?{@fixture.failedAssertBlockWithMessage()})
			assert(@fixture.failedMessage == "failed assertBlock")
		end
		def testSuccessfulAssert
			assert(! fails?{@fixture.successfulAssert()})
			assert(@fixture.successfulMessage == "successful assert")
		end
		def testFailedAssert
			assert(fails?{@fixture.failedAssertPlain()})
			assert(fails?{@fixture.failedAssertWithMessage()})
			assertEqual("failed assert", @fixture.failedMessage, "The failed assertion message should be correct")
		end
		def testErrorInAssert
			rescued = false
			begin
				catch :assertionFailed do
					@fixture.errorInAssert()
				end
			rescue RuntimeError
				rescued = true
			end
			assert(rescued, "Should have rescued the assertion")
		end
		def testAssertEqual
			assert(! fails?{@fixture.successfulAssertEqual}, "Should not have failed if the assertEquals evaluated true")
			assertEqual("successful assertEqual. Expected <string1> but was <string1>", @fixture.successfulMessage, "The message should be correct for a successful assertEqual")

			assert(fails?{@fixture.failedAssertEqualPlain()}, "Should have failed if the arguments to assertEqual were not equal")
			assert(fails?{@fixture.failedAssertEqualWithMessage()}, "Should have failed if the arguments to assertEqual were not equal")
			assertEqual("failed assertEqual. Expected <string1> but was <string2>", @fixture.failedMessage, "The message should have been correct for a failed assertEqual")
		end
		def testAssertRaises
			assert(! fails?{@fixture.successfulAssertRaises}, "Should not fail if the assertions raised exceptions")
			assert(@fixture.successfulMessage["successful assertRaises. Expected exception to be of type <RuntimeError> but was <RuntimeError: Error\n\t"], "The message should be correct for a successful assertRaises")

			assert(fails?{@fixture.failedAssertRaisesPlain}, "Should fail if the assertion did not throw an exception")
			assert(fails?{@fixture.failedAssertRaisesWithMessage}, "Should fail if the assertion did not throw an exception")
			assertEqual("failed assertRaises", @fixture.failedMessage, "The message should be correct for a failed assertRaises")
		end
		def testAssertInstanceOf
			assert(! fails?{@fixture.successfulAssertInstanceOf}, "Should not fail if the object was an instance of the class")
			assertEqual("successful assertInstanceOf. Expected <Array> but was <Array>", @fixture.successfulMessage, "The message should be correct for a successful assertInstanceOf")

			assert(fails?{@fixture.failedAssertInstanceOfPlain}, "Should fail if the object was not an instance of the class")
			assert(fails?{@fixture.failedAssertInstanceOfWithMessage}, "Should fail if the object was not an instance of the class")
			assertEqual("failed assertInstanceOf. Expected <Hash> but was <Array>", @fixture.failedMessage, "The message should be correct for a failed assertInstanceOf")
		end
		def testAssertNil
			assert(! fails?{@fixture.successfulAssertNil}, "Should not fail if the object was nil")
			assertEqual("successful assertNil. Expected <nil> but was <nil>", @fixture.successfulMessage, "The message should be correct for a successful assertNil")

			assert(fails?{@fixture.failedAssertNilPlain}, "Should fail if the object was not nil")
			assert(fails?{@fixture.failedAssertNilWithMessage}, "Should fail if the object was not nil")
			assertEqual("failed assertNil. Expected <nil> but was <string>", @fixture.failedMessage, "The message should be correct for a failed assertNil")
		end
		def testAssertKindOf
			assert(! fails?{@fixture.successfulAssertKindOf}, "Should not fail if the object was a kind of the class")
			assertEqual("successful assertKindOf. Expected <string> to be kind_of?<Object>", @fixture.successfulMessage, "The message should be correct for a successful assertKindOf")

			assert(fails?{@fixture.failedAssertKindOfPlain}, "Should fail if the object was not a kind of the class")
			assert(fails?{@fixture.failedAssertKindOfWithMessage}, "Should fail if the object was not a kind of the class")
			assertEqual("failed assertKindOf. Expected <string> to be kind_of?<Class>", @fixture.failedMessage, "The message should be correct for a failed assertKindOf")
		end
		def testAssertMatch
			assert(! fails?{@fixture.successfulAssertMatch}, "Should not fail if the string matched the regexp")
			assertEqual("successful assertMatch. Expected <string> to match regexp </string/>", @fixture.successfulMessage, "The message should be correct for a successful assertMatch")

			assert(fails?{@fixture.failedAssertMatchPlain}, "Should fail if the string did not match the regexp")
			assert(fails?{@fixture.failedAssertMatchWithMessage}, "Should fail if the string did not match the regexp")
			assertEqual("failed assertMatch. Expected <string> to match regexp </sling/>", @fixture.failedMessage, "The message should be correct for a failed assertMatch")
		end
	end
end
