=begin
=TF_Assertions.rb
A test fixture for testing the Assertions module
=end

#<standard_header>
#
# Copyright (C) 2000-2001 Nathaniel Talbott
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#
#</standard_header>

require 'Lapidary/Assertions'

module Lapidary
	class TF_Assertions
		include Assertions

		attr_reader(:successfulMessage, :failedMessage)

		def successfulAssertBlock
			assertBlock {true}
			assertBlock("successful assertBlock") {true}

			assert_block("successful assertBlock") {true}
		end
		def failedAssertBlockPlain
			assertBlock {false}
		end
		def failedAssertBlockWithMessage
			assertBlock("failed assertBlock") {false}
		end

		def successfulAssert
			assert(true)
			assert(true, "successful assert")
		end
		def failedAssertPlain
			assert(false)
		end
		def failedAssertWithMessage
			assert(false, "failed assert")
		end

		def errorInAssert
			assertBlock("errorAssert") {raise "Error"}
		end

		def successfulAssertEqual
			assertEqual("string1", "string1")
			assertEqual( "string1", "string1", "successful assertEqual")

			assert_equal("string1", "string1", "successful assertEqual")
		end
		def failedAssertEqualPlain
			assertEqual("string1", "string2")
		end
		def failedAssertEqualWithMessage
			assertEqual("string1", "string2", "failed assertEqual")
		end

		def successfulAssertRaises
			assertRaises(RuntimeError) {
				raise "Error"
			}
			assertRaises(ArgumentError, "successful assertRaises") {
				raise ArgumentError.new("Error")
			}

			assert_exception(RuntimeError) {
				raise "Error"
			}

			assert_raises(RuntimeError, "successful assertRaises") {
				raise "Error"
			}
		end
		def failedAssertRaisesPlain
			assertRaises(RuntimeError) {
				1 + 1
			}
		end
		def failedAssertRaisesWithMessage
			assertRaises(RuntimeError, "failed assertRaises") {
				1 + 1
			}
		end

		def successfulAssertInstanceOf
			assertInstanceOf(Array, Array.new)
			assertInstanceOf(Array, Array.new, "successful assertInstanceOf")

			assert_instance_of(Array, Array.new, "successful assertInstanceOf")
		end
		def failedAssertInstanceOfPlain
			assertInstanceOf(Array, Hash.new)
		end
		def failedAssertInstanceOfWithMessage
			assertInstanceOf(Hash, Array.new, "failed assertInstanceOf")
		end

		def successfulAssertNil
			assertNil(nil)
			assertNil(nil, "successful assertNil")

			assert_nil(nil, "successful assertNil")
		end
		def failedAssertNilPlain
			assertNil("string")
		end
		def failedAssertNilWithMessage
			assertNil("string", "failed assertNil")
		end

		def successfulAssertKindOf
			assertKindOf(Array, Module)
			assertKindOf("string", Object, "successfulAssertKindOf")

			assert_kind_of("string", Object, "successful assertKindOf")
		end
		def failedAssertKindOfPlain
			assertKindOf("string", Class)
		end
		def failedAssertKindOfWithMessage
			assertKindOf("string", Class, "failed assertKindOf")
		end

		def successfulAssertMatch
			assertMatch("string", /string/)
			assertMatch("string", /string/, "successfulAssertMatch")

			assert_match("string", /string/, "successful assertMatch")
		end
		def failedAssertMatchPlain
			assertMatch("string", /sling/)
		end
		def failedAssertMatchWithMessage
			assertMatch("string", /sling/, "failed assertMatch")
		end

		def addSuccessfulAssertion(message)
			@successfulMessage = message
		end
		def addFailedAssertion(message)
			@failedMessage = message
		end
	end
end
